import useDrupalJsonApi from 'hooks/drupal_jsonapi';
import LabelBlock from 'molecules/LabelBlock';
import SelectBlock from 'molecules/SelectBlock';
import { useEffect, useState } from 'react';

/**
 * Block of select view.
 *
 * @param 
 */
const UrlSelectBlock = ({ label, value, setValue, url, cloudContext, required, readOnly }: {
  label: string,
  value: string,
  setValue: (s: string) => void,
  url: string,
  cloudContext: string,
  required: boolean,
  readOnly: boolean,
}) => {

  const { getJsonData } = useDrupalJsonApi();
  const [recordList, setRecordList] = useState<{ value: string, label: string, group?: string }[]>([]);

  useEffect(() => {
    getJsonData<{ value: string, label: string, group?: string }[]>(
      url.replace('{cloud_context}', cloudContext)
    ).then((d) => {
      setRecordList(d);
    })
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [cloudContext]);

  if (readOnly) {
    const filtered = recordList.filter((r) => r.value === value);
    return <LabelBlock
      name={label}
      value={filtered.length >= 1 ? filtered[0].label : ''} />;
  }

  return <SelectBlock
    label={label}
    value={value}
    setValue={setValue}
    recordList={recordList}
    required={required} />;
}

export default UrlSelectBlock;
